/* Warning: some computations may require some time to complete */

//* Section 3 - The stepp package *//
sysuse simdataKM, clear

stepp time trt, covsubpop(covar) failure(censor) type(km) ///
	patspop(300) minpatspop(200) trts(1 2) timepoint(4.0) nperm(500) ///
	seed(101)

steppplot, all ytitle("Survival") ryscale(-1 7) ///
  trtlabs(1 "Treatment 1" 2 "Treatment 2")

//* Section 4 - Application *//
sysuse bigCI, clear

stepp time trt, wintype(sliding_events) type(ci) covsubpop(ki67) ///
	comprisk(event) eventspop(15) mineventspop(5) trts(1 2) ///
	timepoint(4.0) nperm(2500) seed(101)

steppplot, trteff diff ratio ///
	ytitle("4-Year Cumulative Incidence of BCR (%)") ///
	xtitle("Median Ki-67 in Subpopulations (% immunoreactivity)") ///
	trtlabs(1 Letrozole 2 Tamoxifen) ///
	tyscale(0 20) dyscale(-30 30) ryscale(0 2.8)

// sensitivity analysis (not reported in the paper)
local mineventspop "8 10 12"
local n_e1: list sizeof mineventspop
local eventspop "15 20 25"
local n_e2: list sizeof eventspop
set seed 101
local nperm = 2500
local n_res = `n_e1'*`n_e2'
tempname all_pv
matrix define `all_pv' = J(`n_res', 3, .)
local cnt = 1
foreach i of local mineventspop {
  foreach j of local eventspop {
	  display "e1 = `i' - e2 = `j'"
		quietly stepp time trt, wintype(sliding_events) type(ci) covsubpop(ki67) ///
	    comprisk(event) eventspop(`j') mineventspop(`i') trts(1 2) ///
	    timepoint(4.0) nperm(`nperm')
		matrix `all_pv'[`cnt', 1] = e(pvalue_1)
		matrix `all_pv'[`cnt', 2] = e(chi2pvalue_1)
		matrix `all_pv'[`cnt', 3] = e(HRpvalue_1)
		local nm_pv "`nm_pv'e1_`i'-e2_`j' "
		local ++cnt
	}
}
matrix colnames `all_pv' = sup_pv chi2_pv HR_pv
matrix rownames `all_pv' = `nm_pv'
matrix list `all_pv'

//* Supplementary Material - Efficacy of aspirin in preventing colorectal adenomas *//
sysuse aspirin, clear

// remove missing values
drop if missing(AD, AL)

// extract the subset of patients randomized to either
// placedo or 81 mg/day
drop if DOSE == 325

// create outcome indicator
generate Y = (AD == 1 | AL == 1)

// create treatment indicator
generate trt = (DOSE != 0)

// STEPP analysis
local minpatspop 30
local patspop 100

stepp Y trt, wintype(sliding) type(glm) covsubpop(AGE) ///
	family("binomial") link("logit") patspop(`patspop') ///
	minpatspop(`minpatspop') trts(0 1) nperm(2500) seed(101)

steppplot, trteff diff ratio ///
	ytitle("Risk of Colorectal Adenomas") ///
	xtitle("Median Age in Subpopulations") ///
	trtlabs(1 "Placebo" 2 "81 mg/day Aspirin") ///
	tyscale(10 70) dyscale(-30 60) ryscale(0 12)
